@@ -1,6 +1,8 @@
 // Copyright (C) 2023 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
+#undef QT_NO_FOREACH // this file contains unported legacy Q_FOREACH uses
+
 #include "abstract3dcontroller_p.h"
 #include "qabstract3daxis_p.h"
 #include "qvalue3daxis_p.h"
@@ -25,11 +27,11 @@ Abstract3DController::Abstract3DController(QRect initialViewport, Q3DScene *scen
     QObject(parent),
     m_themeManager(new ThemeManager(this)),
     m_selectionMode(QAbstract3DGraph::SelectionItem),
-    m_shadowQuality(QAbstract3DGraph::ShadowQualityMedium),
+    m_shadowQuality(QAbstract3DGraph::ShadowQuality::Medium),
     m_useOrthoProjection(false),
     m_aspectRatio(2.0),
     m_horizontalAspectRatio(0.0),
-    m_optimizationHints(QAbstract3DGraph::OptimizationDefault),
+    m_optimizationHint(QAbstract3DGraph::OptimizationHint::Default),
     m_reflectionEnabled(false),
     m_reflectivity(0.5),
     m_locale(QLocale::c()),
@@ -44,7 +46,7 @@ Abstract3DController::Abstract3DController(QRect initialViewport, Q3DScene *scen
     m_renderPending(false),
     m_isPolar(false),
     m_radialLabelOffset(1.0f),
-    m_clickedType(QAbstract3DGraph::ElementNone),
+    m_clickedType(QAbstract3DGraph::ElementType::None),
     m_selectedLabelIndex(-1),
     m_selectedCustomItemIndex(-1),
     m_margin(-1.0)
@@ -54,12 +56,11 @@ Abstract3DController::Abstract3DController(QRect initialViewport, Q3DScene *scen
     m_scene->setParent(this);
 
     // Set initial theme
-    Q3DTheme *defaultTheme = new Q3DTheme(Q3DTheme::ThemeQt);
+    Q3DTheme *defaultTheme = new Q3DTheme(Q3DTheme::Theme::Qt);
     defaultTheme->d_func()->setDefaultTheme(true);
     setActiveTheme(defaultTheme);
 
     m_scene->d_func()->setViewport(initialViewport);
-    m_scene->activeLight()->setAutoPosition(true);
 
     connect(m_scene->d_func(), &Q3DScenePrivate::needRender, this,
             &Abstract3DController::emitNeedRender);
@@ -237,7 +238,7 @@ void Abstract3DController::setAxisX(QAbstract3DAxis *axis)
 {
     // Setting null axis will always create new default axis
     if (!axis || axis != m_axisX) {
-        setAxisHelper(QAbstract3DAxis::AxisOrientationX, axis, &m_axisX);
+        setAxisHelper(QAbstract3DAxis::AxisOrientation::X, axis, &m_axisX);
         emit axisXChanged(m_axisX);
     }
 }
@@ -251,7 +252,7 @@ void Abstract3DController::setAxisY(QAbstract3DAxis *axis)
 {
     // Setting null axis will always create new default axis
     if (!axis || axis != m_axisY) {
-        setAxisHelper(QAbstract3DAxis::AxisOrientationY, axis, &m_axisY);
+        setAxisHelper(QAbstract3DAxis::AxisOrientation::Y, axis, &m_axisY);
         emit axisYChanged(m_axisY);
     }
 }
@@ -265,7 +266,7 @@ void Abstract3DController::setAxisZ(QAbstract3DAxis *axis)
 {
     // Setting null axis will always create new default axis
     if (!axis || axis != m_axisZ) {
-        setAxisHelper(QAbstract3DAxis::AxisOrientationZ, axis, &m_axisZ);
+        setAxisHelper(QAbstract3DAxis::AxisOrientation::Z, axis, &m_axisZ);
         emit axisZChanged(m_axisZ);
     }
 }
@@ -296,13 +297,13 @@ void Abstract3DController::releaseAxis(QAbstract3DAxis *axis)
 
         // If the axis is in use, replace it with a temporary one
         switch (axis->orientation()) {
-        case QAbstract3DAxis::AxisOrientationX:
+        case QAbstract3DAxis::AxisOrientation::X:
             setAxisX(0);
             break;
-        case QAbstract3DAxis::AxisOrientationY:
+        case QAbstract3DAxis::AxisOrientation::Y:
             setAxisY(0);
             break;
-        case QAbstract3DAxis::AxisOrientationZ:
+        case QAbstract3DAxis::AxisOrientation::Z:
             setAxisZ(0);
             break;
         default:
@@ -395,20 +396,20 @@ QAbstract3DGraph::ShadowQuality Abstract3DController::shadowQuality() const
     return m_shadowQuality;
 }
 
-void Abstract3DController::setOptimizationHints(QAbstract3DGraph::OptimizationHints hints)
+void Abstract3DController::setOptimizationHint(QAbstract3DGraph::OptimizationHint hint)
 {
-    if (hints != m_optimizationHints) {
-        m_optimizationHints = hints;
+    if (hint != m_optimizationHint) {
+        m_optimizationHint = hint;
         m_changeTracker.optimizationHintChanged = true;
         m_isDataDirty = true;
-        emit optimizationHintsChanged(hints);
+        emit optimizationHintChanged(hint);
         emitNeedRender();
     }
 }
 
-QAbstract3DGraph::OptimizationHints Abstract3DController::optimizationHints() const
+QAbstract3DGraph::OptimizationHint Abstract3DController::optimizationHint() const
 {
-    return m_optimizationHints;
+    return m_optimizationHint;
 }
 
 bool Abstract3DController::isSlicingActive() const
@@ -681,7 +682,7 @@ void Abstract3DController::handleInputViewChanged(QAbstract3DInputHandler::Input
 {
     // When in automatic slicing mode, input view change to primary disables slice mode
     if (m_selectionMode.testFlag(QAbstract3DGraph::SelectionSlice)
-            && view == QAbstract3DInputHandler::InputViewOnPrimary) {
+            && view == QAbstract3DInputHandler::InputView::OnPrimary) {
         setSlicingActive(false);
     }
 
@@ -839,7 +840,7 @@ void Abstract3DController::setAxisHelper(QAbstract3DAxis::AxisOrientation orient
         } else {
             // Disconnect the old axis from use
             QObject::disconnect(oldAxis, 0, this, 0);
-            oldAxis->d_func()->setOrientation(QAbstract3DAxis::AxisOrientationNone);
+            oldAxis->d_func()->setOrientation(QAbstract3DAxis::AxisOrientation::None);
         }
     }
 
@@ -866,11 +867,11 @@ void Abstract3DController::setAxisHelper(QAbstract3DAxis::AxisOrientation orient
     QObject::connect(axis, &QAbstract3DAxis::titleFixedChanged,
                      this, &Abstract3DController::handleAxisTitleFixedChanged);
 
-    if (orientation == QAbstract3DAxis::AxisOrientationX)
+    if (orientation == QAbstract3DAxis::AxisOrientation::X)
         m_changeTracker.axisXTypeChanged = true;
-    else if (orientation == QAbstract3DAxis::AxisOrientationY)
+    else if (orientation == QAbstract3DAxis::AxisOrientation::Y)
         m_changeTracker.axisYTypeChanged = true;
-    else if (orientation == QAbstract3DAxis::AxisOrientationZ)
+    else if (orientation == QAbstract3DAxis::AxisOrientation::Z)
         m_changeTracker.axisZTypeChanged = true;
 
     handleAxisTitleChangedBySender(axis);
@@ -882,7 +883,7 @@ void Abstract3DController::setAxisHelper(QAbstract3DAxis::AxisOrientation orient
     handleAxisTitleVisibilityChangedBySender(axis);
     handleAxisTitleFixedChangedBySender(axis);
 
-    if (axis->type() & QAbstract3DAxis::AxisTypeValue) {
+    if (axis->type() == QAbstract3DAxis::AxisType::Value) {
         QValue3DAxis *valueAxis = static_cast<QValue3DAxis *>(axis);
         QObject::connect(valueAxis, &QValue3DAxis::segmentCountChanged,
                          this, &Abstract3DController::handleAxisSegmentCountChanged);
@@ -962,13 +963,13 @@ QAbstract3DAxis *Abstract3DController::selectedAxis() const
     QAbstract3DAxis *axis = 0;
     QAbstract3DGraph::ElementType type = m_clickedType;
     switch (type) {
-    case QAbstract3DGraph::ElementAxisXLabel:
+    case QAbstract3DGraph::ElementType::AxisXLabel:
         axis = axisX();
         break;
-    case QAbstract3DGraph::ElementAxisYLabel:
+    case QAbstract3DGraph::ElementType::AxisYLabel:
         axis = axisY();
         break;
-    case QAbstract3DGraph::ElementAxisZLabel:
+    case QAbstract3DGraph::ElementType::AxisZLabel:
         axis = axisZ();
         break;
     default:
@@ -1009,7 +1010,7 @@ void Abstract3DController::setOrthoProjection(bool enable)
         emit orthoProjectionChanged(m_useOrthoProjection);
         // If changed to ortho, disable shadows
         if (m_useOrthoProjection)
-            doSetShadowQuality(QAbstract3DGraph::ShadowQualityNone);
+            doSetShadowQuality(QAbstract3DGraph::ShadowQuality::None);
         emitNeedRender();
     }
 }
