@@ -1,6 +1,8 @@
 // Copyright (C) 2023 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
+#undef QT_NO_FOREACH // this file contains unported legacy Q_FOREACH uses
+
 #include "surface3dcontroller_p.h"
 #include "qvalue3daxis_p.h"
 #include "qsurfacedataproxy_p.h"
@@ -69,7 +71,7 @@ bool Surface3DController::isFlatShadingSupported()
 
 void Surface3DController::addSeries(QAbstract3DSeries *series)
 {
-    Q_ASSERT(series && series->type() == QAbstract3DSeries::SeriesTypeSurface);
+    Q_ASSERT(series && series->type() == QAbstract3DSeries::SeriesType::Surface);
 
     Abstract3DController::addSeries(series);
 
