@@ -8,7 +8,6 @@
 #include <QtGraphs/qlogvalue3daxisformatter.h>
 #include <QtGraphs/qbardataproxy.h>
 #include <QtGraphs/q3dscene.h>
-#include <QtGraphs/q3dcamera.h>
 #include <QtGraphs/q3dtheme.h>
 #include <QtGraphs/q3dinputhandler.h>
 #include <QtGraphs/qcustom3ditem.h>
@@ -57,7 +56,7 @@ GraphModifier::GraphModifier(Q3DBars *barchart, QColorDialog *colorDialog)
       m_useNullInputHandler(false),
       m_defaultInputHandler(0),
       m_ownTheme(0),
-      m_builtinTheme(new Q3DTheme(Q3DTheme::ThemeStoneMoss)),
+      m_builtinTheme(new Q3DTheme(Q3DTheme::Theme::StoneMoss)),
       m_customInputHandler(new CustomInputHandler),
       m_extraSeries(0)
 {
@@ -122,7 +121,7 @@ GraphModifier::GraphModifier(Q3DBars *barchart, QColorDialog *colorDialog)
     m_graph->addAxis(m_genericColumnAxis);
 
     m_graph->setActiveTheme(m_builtinTheme);
-    m_graph->setShadowQuality(QAbstract3DGraph::ShadowQualitySoftMedium);
+    m_graph->setShadowQuality(QAbstract3DGraph::ShadowQuality::SoftMedium);
 
     m_temperatureData->setName("Oulu");
     m_temperatureData2->setName("Helsinki");
@@ -313,7 +312,8 @@ void GraphModifier::releaseAxes()
 
 void GraphModifier::releaseSeries()
 {
-    foreach (QBar3DSeries *series, m_graph->seriesList())
+    const auto barSeriesList = m_graph->seriesList();
+    for (const auto &series : barSeriesList)
         m_graph->removeSeries(series);
 }
 
@@ -554,43 +554,43 @@ void GraphModifier::changeStyle()
     static int model = 0;
     switch (model) {
     case 0:
-        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::MeshCylinder);
+        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::Mesh::Cylinder);
         m_graph->seriesList().at(0)->setMeshSmooth(false);
         break;
     case 1:
-        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::MeshCylinder);
+        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::Mesh::Cylinder);
         m_graph->seriesList().at(0)->setMeshSmooth(true);
         break;
     case 2:
-        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::MeshCone);
+        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::Mesh::Cone);
         m_graph->seriesList().at(0)->setMeshSmooth(false);
         break;
     case 3:
-        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::MeshCone);
+        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::Mesh::Cone);
         m_graph->seriesList().at(0)->setMeshSmooth(true);
         break;
     case 4:
-        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::MeshBar);
+        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::Mesh::Bar);
         m_graph->seriesList().at(0)->setMeshSmooth(false);
         break;
     case 5:
-        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::MeshBar);
+        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::Mesh::Bar);
         m_graph->seriesList().at(0)->setMeshSmooth(true);
         break;
     case 6:
-        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::MeshPyramid);
+        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::Mesh::Pyramid);
         m_graph->seriesList().at(0)->setMeshSmooth(false);
         break;
     case 7:
-        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::MeshPyramid);
+        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::Mesh::Pyramid);
         m_graph->seriesList().at(0)->setMeshSmooth(true);
         break;
     case 8:
-        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::MeshBevelBar);
+        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::Mesh::BevelBar);
         m_graph->seriesList().at(0)->setMeshSmooth(false);
         break;
     case 9:
-        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::MeshBevelBar);
+        m_graph->seriesList().at(0)->setMesh(QAbstract3DSeries::Mesh::BevelBar);
         m_graph->seriesList().at(0)->setMeshSmooth(true);
         break;
     }
@@ -601,17 +601,17 @@ void GraphModifier::changeStyle()
 
 void GraphModifier::changePresetCamera()
 {
-    static int preset = Q3DCamera::CameraPresetFrontLow;
+    static int preset = int(QAbstract3DGraph::CameraPreset::FrontLow);
 
-    m_graph->scene()->activeCamera()->setCameraPreset((Q3DCamera::CameraPreset)preset);
+    m_graph->setCameraPreset((QAbstract3DGraph::CameraPreset)preset);
 
-    if (++preset > Q3DCamera::CameraPresetDirectlyBelow)
-        preset = Q3DCamera::CameraPresetFrontLow;
+    if (++preset > int(QAbstract3DGraph::CameraPreset::DirectlyBelow))
+        preset = int(QAbstract3DGraph::CameraPreset::FrontLow);
 }
 
 void GraphModifier::changeTheme()
 {
-    static int theme = Q3DTheme::ThemeQt;
+    static int theme = int(Q3DTheme::Theme::Qt);
 
     Q3DTheme *currentTheme = m_graph->activeTheme();
     m_builtinTheme->setType(Q3DTheme::Theme(theme));
@@ -619,37 +619,34 @@ void GraphModifier::changeTheme()
         m_graph->setActiveTheme(m_builtinTheme);
 
     switch (theme) {
-    case Q3DTheme::ThemeQt:
-        qDebug() << __FUNCTION__ << "ThemeQt";
+    case int(Q3DTheme::Theme::Qt):
+        qDebug() << __FUNCTION__ << "Qt";
         break;
-    case Q3DTheme::ThemePrimaryColors:
-        qDebug() << __FUNCTION__ << "ThemePrimaryColors";
+    case int(Q3DTheme::Theme::PrimaryColors):
+        qDebug() << __FUNCTION__ << "PrimaryColors";
         break;
-    case Q3DTheme::ThemeDigia:
-        qDebug() << __FUNCTION__ << "ThemeDigia";
+    case int(Q3DTheme::Theme::StoneMoss):
+        qDebug() << __FUNCTION__ << "StoneMoss";
         break;
-    case Q3DTheme::ThemeStoneMoss:
-        qDebug() << __FUNCTION__ << "ThemeStoneMoss";
+    case int(Q3DTheme::Theme::ArmyBlue):
+        qDebug() << __FUNCTION__ << "ArmyBlue";
         break;
-    case Q3DTheme::ThemeArmyBlue:
-        qDebug() << __FUNCTION__ << "ThemeArmyBlue";
+    case int(Q3DTheme::Theme::Retro):
+        qDebug() << __FUNCTION__ << "Retro";
         break;
-    case Q3DTheme::ThemeRetro:
-        qDebug() << __FUNCTION__ << "ThemeRetro";
+    case int(Q3DTheme::Theme::Ebony):
+        qDebug() << __FUNCTION__ << "Ebony";
         break;
-    case Q3DTheme::ThemeEbony:
-        qDebug() << __FUNCTION__ << "ThemeEbony";
-        break;
-    case Q3DTheme::ThemeIsabelle:
-        qDebug() << __FUNCTION__ << "ThemeIsabelle";
+    case int(Q3DTheme::Theme::Isabelle):
+        qDebug() << __FUNCTION__ << "Isabelle";
         break;
     default:
         qDebug() << __FUNCTION__ << "Unknown theme";
         break;
     }
 
-    if (++theme > Q3DTheme::ThemeIsabelle)
-        theme = Q3DTheme::ThemeQt;
+    if (++theme > int(Q3DTheme::Theme::Isabelle))
+        theme = int(Q3DTheme::Theme::Qt);
 }
 
 void GraphModifier::changeLabelStyle()
@@ -695,7 +692,9 @@ void GraphModifier::handleSelectionChange(const QPoint &position)
 {
     m_selectedBar = position;
     int index = 0;
-    foreach (QBar3DSeries *series, m_graph->seriesList()) {
+
+    const auto barSeriesList = m_graph->seriesList();
+    for (const auto &series : barSeriesList) {
         if (series == sender()) {
             if (series->selectedBar() != QBar3DSeries::invalidSelectionPosition())
                 m_selectedSeries = series;
@@ -1503,7 +1502,7 @@ void GraphModifier::setCameraTargetX(int value)
 {
     // Value is (-100, 100), normalize
     m_cameraTarget.setX(float(value) / 100.0f);
-    m_graph->scene()->activeCamera()->setTarget(m_cameraTarget);
+    m_graph->setCameraTargetPosition(m_cameraTarget);
     qDebug() << "m_cameraTarget:" << m_cameraTarget;
 }
 
@@ -1511,7 +1510,7 @@ void GraphModifier::setCameraTargetY(int value)
 {
     // Value is (-100, 100), normalize
     m_cameraTarget.setY(float(value) / 100.0f);
-    m_graph->scene()->activeCamera()->setTarget(m_cameraTarget);
+    m_graph->setCameraTargetPosition(m_cameraTarget);
     qDebug() << "m_cameraTarget:" << m_cameraTarget;
 }
 
@@ -1519,7 +1518,7 @@ void GraphModifier::setCameraTargetZ(int value)
 {
     // Value is (-100, 100), normalize
     m_cameraTarget.setZ(float(value) / 100.0f);
-    m_graph->scene()->activeCamera()->setTarget(m_cameraTarget);
+    m_graph->setCameraTargetPosition(m_cameraTarget);
     qDebug() << "m_cameraTarget:" << m_cameraTarget;
 }
 
@@ -1574,13 +1573,13 @@ void GraphModifier::setGridEnabled(int enabled)
 void GraphModifier::rotateX(int rotation)
 {
     m_xRotation = rotation;
-    m_graph->scene()->activeCamera()->setCameraPosition(m_xRotation, m_yRotation);
+    m_graph->setCameraPosition(m_xRotation, m_yRotation);
 }
 
 void GraphModifier::rotateY(int rotation)
 {
     m_yRotation = rotation;
-    m_graph->scene()->activeCamera()->setCameraPosition(m_xRotation, m_yRotation);
+    m_graph->setCameraPosition(m_xRotation, m_yRotation);
 }
 
 void GraphModifier::setFpsMeasurement(int enable)
@@ -1655,10 +1654,10 @@ void GraphModifier::setMaxY(int max)
 void GraphModifier::changeColorStyle(bool checked)
 {
     Q_UNUSED(checked)
-    int style = m_graph->activeTheme()->colorStyle();
+    int style = int(m_graph->activeTheme()->colorStyle());
 
-    if (++style > Q3DTheme::ColorStyleRangeGradient)
-        style = Q3DTheme::ColorStyleUniform;
+    if (++style > int(Q3DTheme::ColorStyle::RangeGradient))
+        style = int(Q3DTheme::ColorStyle::Uniform);
 
     m_graph->activeTheme()->setColorStyle(Q3DTheme::ColorStyle(style));
 }
@@ -1676,7 +1675,7 @@ void GraphModifier::useOwnTheme(bool checked)
         QList<QColor> colors;
         colors.append(QColor(QRgb(0x209fdf)));
         m_ownTheme->setBaseColors(colors);
-        m_ownTheme->setColorStyle(Q3DTheme::ColorStyleUniform);
+        m_ownTheme->setColorStyle(Q3DTheme::ColorStyle::Uniform);
         m_ownTheme->setGridLineColor(QColor(QRgb(0x99ca53)));
         m_ownTheme->setHighlightLightStrength(7.0f);
         m_ownTheme->setLabelBackgroundEnabled(true);
@@ -1736,7 +1735,7 @@ void GraphModifier::setGradient(bool checked)
     m_graph->activeTheme()->setSingleHighlightGradient(singleHighlightGradient);
     m_graph->activeTheme()->setMultiHighlightGradient(multiHighlightGradient);
 
-    m_graph->activeTheme()->setColorStyle(Q3DTheme::ColorStyleObjectGradient);
+    m_graph->activeTheme()->setColorStyle(Q3DTheme::ColorStyle::ObjectGradient);
 }
 
 void GraphModifier::toggleMultiseriesScaling()
