@@ -5,7 +5,6 @@
 #include <QtGraphs/qbar3dseries.h>
 #include <QtGraphs/qvalue3daxis.h>
 #include <QtGraphs/q3dscene.h>
-#include <QtGraphs/q3dcamera.h>
 #include <QtGraphs/q3dtheme.h>
 #include <QtGraphs/qcustom3dlabel.h>
 #include <QtCore/qmath.h>
@@ -31,10 +30,10 @@ VolumetricModifier::VolumetricModifier(QAbstract3DGraph *scatter)
       m_sliceIndexY(0),
       m_sliceIndexZ(0)
 {
-    m_graph->activeTheme()->setType(Q3DTheme::ThemeQt);
-    //m_graph->activeTheme()->setType(Q3DTheme::ThemeIsabelle);
-    m_graph->setShadowQuality(QAbstract3DGraph::ShadowQualityNone);
-    m_graph->scene()->activeCamera()->setCameraPreset(Q3DCamera::CameraPresetFront);
+    m_graph->activeTheme()->setType(Q3DTheme::Theme::Qt);
+    //m_graph->activeTheme()->setType(Q3DTheme::Theme::Isabelle);
+    m_graph->setShadowQuality(QAbstract3DGraph::ShadowQuality::None);
+    m_graph->setCameraPreset(QAbstract3DGraph::CameraPreset::Front);
     m_graph->setOrthoProjection(true);
     //m_graph->scene()->activeCamera()->setTarget(QVector3D(-2.0f, 1.0f, 2.0f));
     m_scatterGraph = qobject_cast<Q3DScatter *>(m_graph);
